namespace elm { namespace app { 
inline ::efl::eolian::return_traits< ::efl::eina::iterator< ::elm::app::client::View>>::type Client::views_get() const
{
   Eina_Iterator * __return_value =  ::elm_app_client_views_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::iterator< ::elm::app::client::View>>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Client::package_get() const
{
   const char * __return_value =  ::elm_app_client_package_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Client::constructor( ::efl::eolian::in_traits< ::efl::eina::string_view>::type package) const
{
    ::elm_app_client_constructor(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(package));
}
inline ::efl::eolian::return_traits<void>::type Client::view_all_close() const
{
    ::elm_app_client_view_all_close(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Client::terminate() const
{
    ::elm_app_client_terminate(this->_eo_ptr());
}
} } 
namespace eo_cxx {
namespace elm { namespace app { 
inline ::efl::eolian::return_traits< ::efl::eina::iterator< ::elm::app::client::View>>::type Client::views_get() const
{
   Eina_Iterator * __return_value =  ::elm_app_client_views_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::iterator< ::elm::app::client::View>>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Client::package_get() const
{
   const char * __return_value =  ::elm_app_client_package_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Client::constructor( ::efl::eolian::in_traits< ::efl::eina::string_view>::type package) const
{
    ::elm_app_client_constructor(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(package));
}
inline ::efl::eolian::return_traits<void>::type Client::view_all_close() const
{
    ::elm_app_client_view_all_close(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Client::terminate() const
{
    ::elm_app_client_terminate(this->_eo_ptr());
}
inline elm::app::Client::operator ::elm::app::Client() const { return *static_cast< ::elm::app::Client const*>(static_cast<void const*>(this)); }
inline elm::app::Client::operator ::elm::app::Client&() { return *static_cast< ::elm::app::Client*>(static_cast<void*>(this)); }
inline elm::app::Client::operator ::elm::app::Client const&() const { return *static_cast< ::elm::app::Client const*>(static_cast<void const*>(this)); }
} } }

